<?php
namespace Zeedhi\DataMining\Common\Service;

use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\Log\Exception;
use Zeedhi\DataMining\Common\Service\ConnectionFactory;
use Zeedhi\DataMining\Common\Service\Mongo\Runner as MongoRunner;
use Zeedhi\DataMining\Common\Util\Environment;

class Connection {

    const COLLECTION_NAME = 'connection';

    /** @var Environment $environment */
    protected $environment;
    /** @var MongoRunner $mongoRunner */
    protected $mongoRunner;

    public function __construct (Environment $environment, MongoRunner $mongoRunner) {
        $this->environment = $environment;
        $this->mongoRunner = $mongoRunner;
    }

    public function findByOrganization($organization) {
        $filterCriteria = new FilterCriteria(self::COLLECTION_NAME);
        $filterCriteria->addCondition('organizationId',FilterCriteria::IN, array($organization,intval($organization)));
        $connections = $this->mongoRunner->findBy($this->environment->getZmartConnection(), $filterCriteria);

        if (count($connections) > 0) {
            return $connections[0];
        }
        throw new \Exception("Connection not found. Organization {$organization}.", 500);
    }

    public function findById($connectionId) {
        $filterCriteria = new FilterCriteria(self::COLLECTION_NAME);
        $filterCriteria->addCondition("_id", $connectionId);
        return $this->mongoRunner->findBy($this->environment->getOrganizationConnection(), $filterCriteria);
    }

    public function getMainConnection() {
        $filterCriteria = new FilterCriteria(self::COLLECTION_NAME);
        $filterCriteria->addCondition("main", true);
        return $this->mongoRunner->findBy($this->environment->getOrganizationConnection(), $filterCriteria);
    }

    public function getConnectionOrMain($connectionId = null) {
        if($connectionId) {
            $connections = $this->findById($connectionId);
        } else {
            $connections = $this->getMainConnection();
        }
        if(count($connections) > 0) {
            return $connections[0];
        } else {
            throw new Exception("Connections not found");
        }
    }

    public function findByCriteria($connectionMongo,$columnName, $value, $operator = '=') {
        $criteria = array( array(
            "columnName" => $columnName,
            "value" => $value,
            "operator" => $operator
        ));

        $filterCriteria = new FilterCriteria('periods', $criteria);
        return $this->mongoRunner->findBy($connectionMongo,$filterCriteria);
    }

    public function findPeriodById($idPeriod) {
        $period = $this->findByCriteria($this->environment->getOrganizationConnection(),'_id', $idPeriod);
        if(empty($period)){
            $period = $this->findByCriteria($this->environment->getZmartConnection(),'_id', $idPeriod);
        }
        return count($period) > 0 ? $period[0] : null;
    }

}
